﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls.DragDrop;
using Telerik.Windows;
using Telerik.Windows.Controls;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Collections;

namespace _313516_DnDManagerExample
{
	public partial class MainPage : UserControl
	{
		public MainPage()
		{
			InitializeComponent();

			myTabControl1.ItemsSource = GenerateItems();
			myTabControl2.ItemsSource = GenerateItems();

			myBook.AddHandler(RadDragAndDropManager.DropQueryEvent, new EventHandler<DragDropQueryEventArgs>(OnDropQuery));
			myTabControl1.AddHandler(RadDragAndDropManager.DropQueryEvent, new EventHandler<DragDropQueryEventArgs>(OnDropQuery));
			myTabControl2.AddHandler(RadDragAndDropManager.DropQueryEvent, new EventHandler<DragDropQueryEventArgs>(OnDropQuery));

			myBook.AddHandler(RadDragAndDropManager.DropInfoEvent, new EventHandler<DragDropEventArgs>(OnDropInfo));
			myTabControl1.AddHandler(RadDragAndDropManager.DropInfoEvent, new EventHandler<DragDropEventArgs>(OnDropInfo));
			myTabControl2.AddHandler(RadDragAndDropManager.DropInfoEvent, new EventHandler<DragDropEventArgs>(OnDropInfo));

			myTabControl1.AddHandler(RadDragAndDropManager.DragQueryEvent, new EventHandler<DragDropQueryEventArgs>(OnDragQuery));
			myTabControl2.AddHandler(RadDragAndDropManager.DragQueryEvent, new EventHandler<DragDropQueryEventArgs>(OnDragQuery));
		}

		private ObservableCollection<Data> GenerateItems()
		{
			ObservableCollection<Data> result = new ObservableCollection<Data>();
			for (int i = 0; i < 5; i++)
			{
				result.Add(new Data()
				{
					Header = "Header" + i,
					Content = "Content" + i
				});
			}
			return result;
		}

		// OnDragQuery event handler
		private void OnDragQuery(object sender, DragDropQueryEventArgs e)
		{
			if (e.Options.Status == DragStatus.DragQuery)
			{
				RadTabItem draggedItem = e.Options.Source as RadTabItem;
				e.QueryResult = true;
				e.Handled = true;
				// Create Drag and Arrow Cue
				ContentControl dragCue = new ContentControl();
				dragCue.Content = draggedItem.DataContext;
				dragCue.ContentTemplate = this.Resources["DragCueTemplate"] as DataTemplate;
				e.Options.DragCue = dragCue;
				e.Options.ArrowCue = RadDragAndDropManager.GenerateArrowCue();
				// Set the payload (this is the item that is currently dragged)
				e.Options.Payload = draggedItem;
			}
			if (e.Options.Status == DragStatus.DropSourceQuery)
			{
				e.QueryResult = true;
				e.Handled = true;
			}
		}

		// OnDropQuery event handler
		private void OnDropQuery(object sender, DragDropQueryEventArgs e)
		{
			if (e.Options.Status == DragStatus.DropDestinationQuery)
			{
				e.Handled = true;
				e.QueryResult = true;
			}
		}

		// OnDropInfo event handler
		private void OnDropInfo(object sender, DragDropEventArgs e)
		{
			RadTabItem payload = e.Options.Payload as RadTabItem;
			var destination = e.Options.Destination;
			if (payload != null && e.Options.Status == DragStatus.DropPossible)
			{
				(payload.DataContext as Data).Status = "DropPossible";
			}

			if (payload != null && e.Options.Status == DragStatus.DropImpossible)
			{
				(payload.DataContext as Data).Status = "DropImPossible";
			}
			if (e.Options.Status == DragStatus.DropComplete)
			{
				if (destination is RadBook)
				{
					//adding a TabControl to the second page
					RadTabControl tabControl = new RadTabControl();
					secondPagePanel.Children.Add(tabControl);

					RadTabItem tabItem = new RadTabItem();
					tabItem.Header = (payload.DataContext as Data).Header;
					tabItem.Content = (payload.DataContext as Data).Content;

					tabControl.Items.Add(tabItem);
				}
				else
					((destination as RadTabControl).ItemsSource as IList).Add(payload.DataContext);

			}
		}

	}
	public class Data : INotifyPropertyChanged
	{
		private string status;
		public string Status
		{
			get
			{
				return status;
			}
			set
			{
				if (value != status)
				{
					status = value;
					OnPropertyChanged("Status");
				}
			}

		}

		public string Header { get; set; }
		public string Content { get; set; }

		/// <summary>
		///     Event for INotifyPropertyChanged.
		/// </summary>
		public event PropertyChangedEventHandler PropertyChanged;

		/// <summary>
		///     Raises the INotifyPropertyChanged event.
		/// </summary>
		/// <param name="propertyName">The property to be included in the INotifyPropertyChanged EventArgs.</param>
		protected virtual void OnPropertyChanged(String propertyName)
		{
			if (PropertyChanged != null)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}
	}
}
